# nbprint-email

Alias for nbprint-plugin-email

[![Build Status](https://github.com/tkp-aliases/nbprint-email/actions/workflows/build.yaml/badge.svg?branch=main&event=push)](https://github.com/tkp-aliases/nbprint-email/actions/workflows/build.yaml)
[![codecov](https://codecov.io/gh/tkp-aliases/nbprint-email/branch/main/graph/badge.svg)](https://codecov.io/gh/tkp-aliases/nbprint-email)
[![License](https://img.shields.io/github/license/tkp-aliases/nbprint-email)](https://github.com/tkp-aliases/nbprint-email)
[![PyPI](https://img.shields.io/pypi/v/nbprint-email.svg)](https://pypi.python.org/pypi/nbprint-email)

## Overview

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
